@@ -39,7 +39,7 @@ sub fetch {
 	# first, see if we've got it cached:
 	$self->_debug("i:haveCache=$haveLyricsCache= -cachedir=".$self->{'-cache'}."=");
 	if ($haveLyricsCache && $self->{'-cache'} && $self->{'-cache'} !~ /^\>/) {
-		my $cache = new Mod::Cache(%{$self});
+		my $cache = new LyricFinder::Cache(%{$self});
 		if ($cache) {
 			my $lyrics = $cache->fetch($artist_in, $song_in);
 			if (defined($lyrics) && $lyrics =~ /\w/) {
@@ -70,7 +70,6 @@ sub fetch {
 		$self->_debug("=== WILL CACHE LYRICS! ===");
 		# cache the fetched lyrics, if we can:
 		my $cache = new LyricFinder::Cache(%{$self});
-		my $res = 0;
 		$cache->save($artist_in, $song_in, $lyrics)  if ($cache);
 	}
 	return $lyrics;
