@@ -41,7 +41,7 @@ sub fetch {
 	# first, see if we've got it cached:
 	$self->_debug("i:haveCache=$haveLyricsCache= -cachedir=".$self->{'-cache'}."=");
 	if ($haveLyricsCache && $self->{'-cache'} && $self->{'-cache'} !~ /^\>/) {
-		my $cache = new Mod::Cache(%{$self});
+		my $cache = new LyricFinder::Cache(%{$self});
 		if ($cache) {
 			my $lyrics = $cache->fetch($artist_in, $song_in);
 			if (defined($lyrics) && $lyrics =~ /\w/) {
@@ -76,7 +76,6 @@ sub fetch {
 		$self->_debug("=== WILL CACHE LYRICS! ===");
 		# cache the fetched lyrics, if we can:
 		my $cache = new LyricFinder::Cache(%{$self});
-		my $res = 0;
 		$cache->save($artist_in, $song_in, $lyrics)  if ($cache);
 	}
 	return $lyrics;
@@ -96,6 +95,13 @@ sub _parse {
 		$goodbit =~ s#\<br\/?\>#\r\n#gsi;
 		my $text = $hs->parse($goodbit);
 
+		#WHILE WE'RE AT IT, SEE IF WE HAVE A COVER IMAGE?!:
+		if ($html =~ m#\<noscript\>\s*\<img\s+src\=\"([^\"]+)#s) {
+			my $imgurl = $1;
+			$imgurl = 'https:' . $imgurl  if ($imgurl =~ m#^//#);
+			$self->{'image_url'} = $imgurl;
+		}
+
 		return $self->_normalize_lyric_text($self->_html2text($text));
 	} else {
 		carp($self->{'Error'} = "e:$Source - Failed to identify lyrics on result page.");
@@ -296,6 +302,12 @@ This is the primary method call, and the only one required to be called
 Returns lyrics as a string (includes line-breaks appropriate for the user's 
 operating system), or an empty string, if no lyrics found.
 
+=item I<$scalar> = $finder->B<image_url>()
+
+Returns a URL for a cover-art image, if one found on the lyrics page.  
+If no image is found, an empty string will be returned if this method 
+is called.
+
 =item I<$scalar> = $finder->B<message>()
 
 Returns the last error string generated, or "Ok" if all's well.
